from .smapi import SteamMarketHandler

__all__ = ['SteamMarketHandler']

__name__ = 'SteamMarketAPI'
__version__ = '0.0.1'

__doc__ = """Steam Market API provides you to use Community Market of CSGO game easily and automatize it."""
